==> openshift-model-installer-6.7.2-sources.jar: io/fabric8/openshift/api/model/installer/ovirt/v1/CPUBuilder.java <==
package io.fabric8.openshift.api.model.installer.ovirt.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CPUBuilder extends CPUFluentImpl<CPUBuilder> implements VisitableBuilder<CPU,CPUBuilder>{
  public CPUBuilder() {
    this(false);
  }
  public CPUBuilder(Boolean validationEnabled) {
    this(new CPU(), validationEnabled);
  }
  public CPUBuilder(CPUFluent<?> fluent) {
    this(fluent, false);
  }
  public CPUBuilder(CPUFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CPU(), validationEnabled);
  }
  public CPUBuilder(CPUFluent<?> fluent,CPU instance) {
    this(fluent, instance, false);
  }
  public CPUBuilder(CPUFluent<?> fluent,CPU instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withCores(instance.getCores());
      fluent.withSockets(instance.getSockets());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public CPUBuilder(CPU instance) {
    this(instance,false);
  }
  public CPUBuilder(CPU instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withCores(instance.getCores());
      this.withSockets(instance.getSockets());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  CPUFluent<?> fluent;
  Boolean validationEnabled;
  public CPU build() {
    CPU buildable = new CPU(fluent.getCores(),fluent.getSockets());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-installer-6.8.0-sources.jar: io/fabric8/openshift/api/model/installer/ovirt/v1/CPUBuilder.java <==
package io.fabric8.openshift.api.model.installer.ovirt.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CPUBuilder extends CPUFluent<CPUBuilder> implements VisitableBuilder<CPU,CPUBuilder>{
  public CPUBuilder() {
    this(false);
  }
  public CPUBuilder(Boolean validationEnabled) {
    this(new CPU(), validationEnabled);
  }
  public CPUBuilder(CPUFluent<?> fluent) {
    this(fluent, false);
  }
  public CPUBuilder(CPUFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CPU(), validationEnabled);
  }
  public CPUBuilder(CPUFluent<?> fluent,CPU instance) {
    this(fluent, instance, false);
  }
  public CPUBuilder(CPUFluent<?> fluent,CPU instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new CPU());

    if (instance != null) {
      fluent.withCores(instance.getCores());
      fluent.withSockets(instance.getSockets());
      fluent.withThreads(instance.getThreads());
      fluent.withCores(instance.getCores());
      fluent.withSockets(instance.getSockets());
      fluent.withThreads(instance.getThreads());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public CPUBuilder(CPU instance) {
    this(instance,false);
  }
  public CPUBuilder(CPU instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new CPU());

    if (instance != null) {
      this.withCores(instance.getCores());
      this.withSockets(instance.getSockets());
      this.withThreads(instance.getThreads());
      this.withCores(instance.getCores());
      this.withSockets(instance.getSockets());
      this.withThreads(instance.getThreads());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  CPUFluent<?> fluent;
  Boolean validationEnabled;
  public CPU build() {
    CPU buildable = new CPU(fluent.getCores(),fluent.getSockets(),fluent.getThreads());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
